package ru.ulstu.meeting;

import org.springframework.format.annotation.DateTimeFormat;
import ru.ulstu.model.BaseEntity;
import ru.ulstu.news.News;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.OneToOne;
import javax.persistence.Transient;
import javax.validation.constraints.NotEmpty;
import java.util.Date;

@Entity
public class Meeting extends BaseEntity {
    @NotEmpty(message = "Заголовок не может быть пустым")
    private String title;

    @DateTimeFormat(pattern = "dd.MM.yyyy HH:mm")
    private Date date;

    @Lob
    @NotEmpty(message = "Текст заседания не может быть пустым")
    private String text;

    @OneToOne(cascade = CascadeType.ALL)
    @JoinColumn(name = "news_id", referencedColumnName = "id")
    private News news;

    @Transient
    private Integer newsId;

    public Meeting() {
    }

    public Meeting(String title, String text, Date date) {
        this.title = title;
        this.date = date;
        this.text = text;
    }

    public String getTitle() {
        return title;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public void setText(String text) {
        this.text = text;
    }

    public String getText() {
        return text;
    }

    public News getNews() {
        return news;
    }

    public void setNews(News news) {
        this.news = news;
    }

    public Integer getNewsId() {
        return newsId == null
                ? (news != null) ? news.getId() : null
                : newsId;
    }

    public void setNewsId(Integer newsId) {
        this.newsId = newsId;
    }
}
